# -*- coding: utf-8 -*-

"""
bitcoins.api
~~~~~~~~~~~~

This module implements the Bitcoins API.

:copyright: (c) 2012 by Kenan Yildirim.
:license: MIT, see LICENSE for more details.

"""

import urllib


def get_difficulty():
    """Retrieves the current difficulty as a multiple of the minimum difficulty
    (highest target).
    """

    d = urllib.urlopen('https://blockexplorer.com/q/getdifficulty')
    return float(d.read())



# -*- coding: utf-8 -*-

#     ____  _ __             _
#    / __ )(_) /__________  (_)___  _____
#   / __  / / __/ ___/ __ \/ / __ \/ ___/
#  / /_/ / / /_/ /__/ /_/ / / / / (__  )
# /_____/_/\__/\___/\____/_/_/ /_/____/

"""
bitcoins Cryptocurrency library
~~~~~~~~~~~~~~~~~~~~~

Bitcoins is an cryptocurrency library, written in Python, for human beings.

:copyright: (c) 2012 by Kenan Yildirim.
:license: MIT, see LICENSE for more details.

"""

__title__ = 'bitcoins'
__version__ = '0.0.0'
__build__ = 0x000000
__author__ = 'Kenan Yildirim'
__license__ = 'MIT'
__copyright__ = 'Copyright 2012 Kenan Yildirim'

from .api import get_difficulty


#!/usr/bin/env python

import os
import sys
import bitcoins

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

if sys.argv[-1] == 'publish':
    os.system('python setup.py sdist upload')
    sys.exit()

os.environ['PYTHONDONTWRITEBYTECODE'] = '1'

packages = ['bitcoins']

requires = []

setup(
    name='bitcoins',
    version=bitcoins.__version__,
    description='Python Bitcoins for Humans.',
    long_description=open('README.rst').read(),
    author='Kenan Yildirim',
    author_email='kenan@kenany.me',
    url='https://github.com/KenanY/bitcoins',
    packages=packages,
    install_requires=requires,
    license=open('LICENSE').read(),
    classifiers=(
        'Development Status :: 1 - Planning',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
    ),
)

del os.environ['PYTHONDONTWRITEBYTECODE']
